class Сообщество:
    """
    Объект списка сообществ, возвращаемый функцией получить_мои_сообщества(...)
    """
    def __init__(self, объект):
        self.объект = объект
        self.название = []
        self.идентификатор = []
        for элемент in объект:
            self.название.append(элемент['name'])
            self.идентификатор.append(элемент['ndcId'])
class Комната:
    """
    Объект списка чатов, возвращаемый функцией получить_мои_комнаты(...)
    """
    def __init__(self, объект):
        self.объект = объект
        self.название = []
        self.идентификатор = []
        for элемент in объект:
            self.название.append(элемент['title'])
            self.идентификатор.append(элемент['threadId'])
class Пользователь:
    """
    Объект списка пользователей, возвращаемый функцией получить_пользователей_в_сети(...)
    """
    def __init__(self, объект):
        self.объект = объект
        self.идентификатор = []
        self.имя = []
        self.профильное_изображение = []
        for элемент in объект:
            self.идентификатор.append(элемент['uid'])
            self.имя.append(элемент['nickname'])
            self.профильное_изображение.append(элемент['icon'])